@@ -483,17 +483,17 @@ function corriger_extension($ext) {
 function fixer_extension_document($doc) {
 	$extension = '';
 	$name = $doc['name'];
-	if (preg_match(',[.]([^.]+)$,', $name, $r)
+	if (preg_match(',\.([^.]+)$,', $name, $r)
 	AND $t = sql_fetsel("extension", "spip_types_documents",
 	"extension=" . sql_quote(corriger_extension($r[1])))) {
 		$extension = $t['extension'];
-		$name = preg_replace(',[.][^.]*$,', '', $doc['name']).'.'.$extension;
+		$name = preg_replace(',\.[^.]*$,', '', $doc['name']).'.'.$extension;
 	} else {
 		// les navigateur devraient savoir que ceci est mime-type text
 		if (strtolower($name) === 'makefile') $doc['type'] = 'txt';
 		if ($t = sql_getfetsel("extension", "spip_types_documents",
 				 "mime_type=" . sql_quote($doc['type']))) {
-		  $name = preg_replace(',[.][^.]*$,', '', $doc['name']).'.'.$t;
+		  $name = preg_replace(',\.[^.]*$,', '', $doc['name']).'.'.$t;
 		}
 	}
 	return array($extension,$name);
