@@ -3,7 +3,7 @@
 // extrait automatiquement de http://www.spip.net/trad-lang/
 // ** ne pas modifier le fichier **
 
-if (!defined("_ECRIRE_INC_VERSION")) return;
+if (!defined('_ECRIRE_INC_VERSION')) return;
 
 $GLOBALS[$GLOBALS['idx_lang']] = array(
 
@@ -651,7 +651,6 @@ Merc&eacute; per la v&ograve;stra participacion
 'onglet_repartition_rubrique' => 'Reparticion per rubricas',
 'onglet_save_restaur_base' => 'Sauvagardar/restaurar la basa',
 'onglet_vider_cache' => 'Vuar l\'escondedor',
-'ortho_trop_de_fautes2' => 'Comen&ccedil;atz per corregir lu errors mai evidents e tornatz assaiar pi.',
 
 // P
 'pass_choix_pass' => 'Vorgatz chausir lo v&ograve;stre mot de santa Clara nov&egrave;u:',
